@@ -29,6 +29,7 @@ from typing import Union, List
 
 from scipy.special import binom
 import scipy
+import scipy.interpolate
 import cv2
 
 
@@ -536,11 +537,13 @@ class InterpolationCurve(ExplicitCurve):
         pass
 
     def calc_point(self, x):
+        # val = self.interpolate(x, order=0)
         x = np.array(x, dtype=np.float)
         extra_mask = self._out_of_range_flag(x)
         val = np.empty_like(x)
         val[extra_mask] = self.extrapolate(x[extra_mask], order=0)  # 数据范围外，按外推规则计算
         val[~extra_mask] = self.interpolate(x[~extra_mask], order=0)  # 数据范围内，插值计算
+        # todo：判断是否在数据范围外的逻辑现在写的太耗时了！降低运算效率70%
         return val
 
     def calc_first_derivative(self, x):
@@ -568,15 +571,15 @@ class InterpolationCurve(ExplicitCurve):
         return val
 
 
-
-class CubicSpline(InterpolationCurve):
+class spCubicSpline(InterpolationCurve):
     """
     CubicSpline class
     三次样条插值
+    todo: scipy自带的在距离很远的时候插值有严重问题，暂时先用自己写的，以后看看为什么有这个问题并且怎么修复
     """
     def __init__(self, x=None, y=None):
         self._sp_csp = None # 屈服了，还是用Scipy的吧
-        super(CubicSpline, self).__init__(x, y)
+        super(spCubicSpline, self).__init__(x, y)
 
     def _calc_coef(self):
         self._sp_csp = scipy.interpolate.CubicSpline(self.x, self.y)
@@ -743,6 +746,10 @@ class myCubicSpline(InterpolationCurve):
 
         return val
 
+
+class CubicSpline(myCubicSpline):
+    pass
+
 class Spline:#Cubic CubicSpline class(abandoned)
     def __init__(self, x, y):
         raise AssertionError("Spline class has been deprecated! Use CubicSpline instead!")
